Repo of the Unknown - #1: October

# #1: October

- Oct 27, 2023
- Categories: Blog
- Tags: #python #balladeer #game jam

## An opportunity arises

It's the end of October. I've been fixing a couple of bugs in Balladeer. I'm happy with it. The code feels pretty solid now.

Maybe it could use just one more teaching example? No ideas yet, however.

In any case, it's going to be a big weekend. New Zealand are playing South Africa in the final of the Rugby World Cup. Probably not the right time to begin a new writing project. Too many distractions right now.

For some reason I visit Itch.io, the game hosting portal. And guess what? Today is the start of the eighth Python Game Jam. An invitation to spend the next ten days in a race to build a game and submit it for judgement by strangers.

So I sign up.

## Set up to fail

I know this is a tall order. The competition is only ten days long. I calculate I'll be lucky if I can average 2 hours a day amidst the other demands on my time. It's unlikely I'll be able to make anything very compelling. But it might generate that missing demo for Balladeer.

The competition theme is announced. It's The Unknown.

So I log in to Github, and I create a new public repository. I call it Repo Of The Unknown.

That will have to be all for now. The Rugby is on.